#if !defined(GrLCD_H)
#define GrLCD_H

typedef unsigned char BYTE;
typedef unsigned short WORD;		// a 16 bit value, processor dependant

#define NR_COLS		160
#define NR_BYTES	(NR_COLS / 8)
#define NR_ROWS		160
#define LASTROW		(NR_ROWS - 1)

// macros for ports for LCD control & data bus

#define E 		0x80	// enable strobe
#define RES 	0x40	// always high after IO port init
#define CS 		0x20	// CS always low
#define RW 		8 		// low unless reading busy flag
#define RS 		4		// cmd/data select

#define LCD_IN		PEIN
#define LCD_OUT		PEOUT
#define DELAY		\
asm ("NOP"); \
asm ("NOP"); \
asm ("NOP"); \

#define LCD_CTRL1(arg1)	PCOUT |= arg1
#define LCD_CTRL0(arg1)	PCOUT &= ~arg1


typedef struct
{
	BYTE cj_code;		// justify, font
	BYTE row;			// start row
	BYTE col;			// start col IF ABSJ, else not used
	const char *text;	// pointer to null terminated string
} String_T;

/* Examples:
String_T str1 = { C50J+FONT16, 25, 0, "Display text" };	// row 25, large font, centered
String_T str2 = { ABSJ, 0, 45, "Display text" };		// row 0, small font, start in col 45
String_T str3 = { L33J, 5, 0, buffer };					// row 5, small font, centered @ 1/3, refering
char buffer[128];										// to string that's not constant
*/

//	text string display control/justification codes

#define FONT16		0x20	// large font
#define NOSPC		0x10	// no space between characters
#define JUSTIFY		7		// bit mask
#define L00J		0		// left, starting @ col 0
#define L25J		1		// left, centered @ 1/4
#define L33J		2		// left, centered @ 1/3
#define C50J		3		// centered @ 1/2
#define R66J		4		// right, centered @ 2/3
#define R75J		5		// right, centered @ 3/4
#define R100J		6		// right, ending @ last col
#define ABSJ		7		// starting @ abs col #

extern BYTE CJ_code;		// control/justify code for text display
extern BYTE startcol;		// save starting col for later use
extern BYTE linenr;
extern int gr_x, gr_y;

void LCDInit(void);
void LCDSet(BYTE cmd, BYTE arg);
void LCDCmd(BYTE arg);
void LCDData(BYTE arg);
void LCDClear(BYTE srow, BYTE hgt);
void LCDText(String_T *text);
void LCDErase(BYTE srow, BYTE scol, BYTE erow, BYTE ecol);
void LCDScrollText(BYTE srow, BYTE scol, BYTE erow, BYTE ecol, String_T *txt, int rate);
void LCDSetCur(WORD addr);
BYTE LCDPixLen(const char *chr);
BYTE LCDRead(void);
void point(int x, int y);
void lineto(int x2, int y2);

#endif
